#ifndef __TCS230_H
#define __TCS230_H

/*  
	This is a library to interface with the Taos TCS230 Light to frequency 
	sensor. Please extract it into the Arduino library folder which is 
	usually:
		C:\Program Files\arduino-0016\hardware\libraries
	
	The pins of the TCS230 can either be hooked up to the Arduino 
	or by using John Sarik's custom TCS230 to Arduino Mounting board. The 
	default constructor assumes this board is being used. 
	
	To use this library:
		1. Wire up the TCS230 to your Arduino
		2. Type #include <TCS230.h> at the top of your code
		3. Initialize a TCS230 object in your Arduino code outside the 
		   program functions. For example
		   
		   TCS230 sensor; //creates object called sensor
		4. If the TCS230 is wired in the following manner, then no 
		   parameters need to be passed:
		   
		   gnd =  Arduino Pin 8
		    oe =  Arduino Pin 7
		    s1 =  Arduino Pin 6
		    s0 =  Arduino Pin 5 
		    s2 =  Arduino Pin 3
		    s3 =  Arduino Pin 4
		   out =  Arduino Pin 2
		   vdd =  Arduino Pin 9 
		   
		   Otherwise, pass the pin numbers of the Arduino that the pins of
		   the TCS230 are attached to in the order above. 
		5. Within the setup function, call the initialize function for the 
		   object. For example:
				
				sensor.initialize(); //initialize sensor object
		6. In order to read from the TCS230, call the read functions. 
		   For example: 
				
				Sensor.readRed(); //read red photodiodes on TCS230
				Sensor.readBlue(); //read blue photodiodes on TCS230
				Sensor.readGreen(); //read green photodiodes on TCS230
				Sensor.readClear(); //read clear photodiodes on TCS230
			
			These functions return half the value of the period of the 
			square wave outputted by the TCS230 in microseconds. 
			Therefore, the higher the light intensity, the smaller the 
			number and vice versa. 
			
	Enjoy using my library!
	
	
*/

#include "WProgram.h"

class TCS230
{
public:
	//constructor
	TCS230(int gnd, int oe, int out, int s0, int s1, int s2, int s3, int vdd);
	//default constructor
	TCS230(); 
	//function to initialize
	void initialize();
	
	//color reading functions
	int  readRed(); 
	int  readBlue(); 
	int  readClear(); 
	int  readGreen(); 
	
private:
	byte _gnd, _oe, _out, _s0, _s1, _s2, _s3, _vdd; //pin assignments
	
	
};




#endif